@@ -21,5 +21,5 @@ CPCdata.frame <- function(data, cols, clusters) {
   new_data <- as.data.frame(data[,cols])
   new_clusters <- as.data.frame(data[,clusters])
   colnames(new_clusters) <- "cluster"
-  cbind(new_data, new_clusters)
+  na.omit(cbind(new_data, new_clusters))
 }
